# gecasmo
The `gecasmo` Python package, for estimating click models with covariates using EM.

## Installing
```shell
pip install gecasmo
```

## Examples

The `/notebooks` directory contains a set of [Jupyter Notebook examples](https://github.com/cornederuijt/gecasmo/notebooks), including the following click models:

* [CZM](https://github.com/Mogeng/IOHMM/blob/master/examples/notebooks/UnSupervisedIOHMM.ipynb), also known as DBN [[1]](#1)

* [UBM](https://github.com/Mogeng/IOHMM/blob/master/examples/notebooks/SemiSupervisedIOHMM.ipynb) [[2]](#2)

## References
<a id="1">[1]</a> 
Chapelle, Olivier, and Ya Zhang. (2009). 
A dynamic bayesian network click model for web search ranking.
Proceedings of the 18th international conference on World wide web. ACM, 1–10.

<a id="2">[2]</a> 
Dupret, Georges E. and Piwowarski, Benjamin. (2008). 
A user browsing model to predict search engine click data from past observations.
Proceedings of the 31st annual international ACM SIGIR conference on Research and development in information retrieval. ACM, 331--338.

## Licensing
The MIT Licence (MIT)
